relabel_overlay_mountpoints

Function relabel_overlay_mountpoints 

pub(crate) fn relabel_overlay_mountpoints() -> Result<()>
Relabel transient overlay mount point inodes using the running SELinux policy. Called by the generated bootc-early-overlay-relabel.service oneshot to fix the tmpfs_t label that fs_use_trans assigns to overlay upper-dir inodes at policy-load time. Each of /, /etc, /var is relabelled iff it is a writable overlayfs (i.e. a transient overlay, not the read-only composefs).